//@line 36 "/builds/moz2_slave/rel-192-lnx-rpk-6/l10n-mozilla-1.9.2/te/browser/firefox-l10n.js"

//@line 38 "/builds/moz2_slave/rel-192-lnx-rpk-6/l10n-mozilla-1.9.2/te/browser/firefox-l10n.js"

pref("general.useragent.locale", "te");
